@@ -20,12 +20,11 @@
 #include "gui/editmountoptionsdialogwidget.h"
 
 #include <QDialogButtonBox>
-#include <QString>
 #include <QStringList>
 
 #include <KConfigGroup>
-#include <KSharedConfig>
 #include <KLocalizedString>
+#include <KSharedConfig>
 
 EditMountOptionsDialog::EditMountOptionsDialog(QWidget* parent, const QStringList& options) :
     QDialog(parent),
@@ -34,7 +33,7 @@ EditMountOptionsDialog::EditMountOptionsDialog(QWidget* parent, const QStringLis
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setLayout(mainLayout);
     mainLayout->addWidget(&widget());
-    setWindowTitle(i18nc("@title:window", "Edit additional mount options"));
+    setWindowTitle(xi18nc("@title:window", "Edit additional mount options"));
 
     KConfigGroup kcg(KSharedConfig::openConfig(), "editMountOptionsDialog");
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
@@ -58,7 +57,7 @@ QStringList EditMountOptionsDialog::options()
 {
     QStringList rval;
     const QStringList lines = widget().editOptions().toPlainText().split(QStringLiteral("\n"));
-    foreach(const QString & line, lines)
-    rval.append(line.simplified().toLower());
+    for (const auto &line : lines)
+        rval.append(line.simplified().toLower());
     return rval;
 }
